/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.web.listener;

import java.io.File;

import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

import ch.hortis.sonar.SonarProperties;
import ch.hortis.sonar.core.repository.MavenRepository;

public class SonarMavenRepositoryBuilder implements ServletContextListener {

  private MavenRepository repository;

  public void contextInitialized(ServletContextEvent sce) {
    String currentJDBCDialect = SonarContext.getInstance().get(SonarContext.JDBC_DIALECT_CONTEXT_KEY);
    repository = new MavenRepository(currentJDBCDialect, getSonarRootSysProp(), getWebAppPublicDir(sce));
    try {
      repository.build();
    } catch (Exception e) {
      throw new IllegalStateException("Error occured during maven repository building", e);
    }
  }

  public void contextDestroyed(ServletContextEvent sce) {
    if ( repository == null ) return;
    try {
      repository.destroy();
    } catch (Exception e) {
      throw new IllegalStateException("Error occured during maven repository destruction", e);
    }
  }
  
  private File getSonarRootSysProp() {
    File sonarRoot;
    try {
      sonarRoot = new File(SonarProperties.getSonarRoot());
    } catch (Exception e) {
      throw new IllegalStateException("Unable to get sonar root", e);
    }
    if (!sonarRoot.exists()) {
      throw new IllegalStateException("Sonar root " + sonarRoot.getPath()+ " does not exists");
    }
    return sonarRoot;
  }
  
  private File getWebAppPublicDir(ServletContextEvent sce) {
    String webAppPublicDirPath = sce.getServletContext().getRealPath("/public/");
    if (webAppPublicDirPath == null) {
      throw new IllegalStateException("Unable to get sonar web app '/public/' directory path");
    }
    File webAppPublicDir = new File(webAppPublicDirPath);
    if (!webAppPublicDir.exists()) {
      throw new IllegalStateException("Path " + webAppPublicDir.getPath()+ " does not exists");
    }
    return new File( webAppPublicDir, "maven");
  }
}
